import request from '@/utils/request'
//查询分销订单列表
export function orderPage (query) {
  return request({
    url: `/system/distribution/order/page`,
    method: 'get',
    params: query
  })
}
// 新增地推信息
export function fieldPromotionAdd (data) {
  return request({
    url: `/system/fieldPromotion/add`,
    method: 'post',
    data
  })
}
// 修改地推信息
export function fieldPromotionEdit (data) {
  return request({
    url: `/system/fieldPromotion/edit`,
    method: 'post',
    data
  })
}
// 查询地推信息列表
export function fieldPromotionPage (query) {
  return request({
    url: `/system/fieldPromotion/page`,
    method: 'get',
    params: query
  })
}
// 删除地推信息

export function fieldPromotionDel (promotionIds) {
  return request({
    url: `/system/fieldPromotion/del/${promotionIds}`,
    method: 'post',
  })
}
// 获取地推信息详细信息
export function fieldPromotionInfo (promotionId) {
  return request({
    url: `/system/fieldPromotion/info/${promotionId}`,
    method: 'get',
  })
}
// 启用-禁用 地推信息
export function fieldPromotionStatus (data) {
  return request({
    url: `/system/fieldPromotion/status`,
    method: 'post',
    data: data
  })
}
// 获取分销订单详细信息
export function orderInfo (distributionOrderId) {
  return request({
    url: `/system/distribution/order/info/${distributionOrderId}`,
    method: 'get',
  })
}
// 查询分销提现列表

export function withdrawalPage (query) {
  return request({
    url: `/system/distribution/withdrawal/page`,
    method: 'get',
    params: query
  })
}